<?php

declare(strict_types=1);

namespace Drupal\tour;

use Drupal\Core\Render\ElementInfoManagerInterface;
use Drupal\Core\Security\TrustedCallbackInterface;

/**
 * Defines a class for lazy building render arrays.
 *
 * @internal
 */
final class LazyBuilders implements TrustedCallbackInterface {

  /**
   * Constructs LazyBuilders object.
   *
   * @param \Drupal\Core\Render\ElementInfoManagerInterface $elementInfo
   *   Element info.
   */
  public function __construct(
    protected ElementInfoManagerInterface $elementInfo,
  ) {
  }

  /**
   * Render tour.
   *
   * @param bool $noTips
   *   Indicates if the current page has any tour.
   *
   * @return array
   *   Render array.
   */
  public function renderTour(bool $noTips = FALSE): array {
    return [
      '#type' => 'html_tag',
      '#tag' => 'button',
      '#value' => $noTips ? t('No tour available for this page.') : t('Take a tour of this page'),
      '#attributes' => [
        'class' => [
          'toolbar-icon',
          'toolbar-item',
          'toolbar-icon-help',
        ],
        'aria-pressed' => 'false',
        'type' => 'button',
        'disabled' => $noTips,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks(): array {
    return ['renderTour'];
  }

}
