<?php

namespace Drupal\Tests\tour\Functional\Language;

use Drupal\Tests\tour\Functional\TourTestBase;

/**
 * Tests tour functionality.
 *
 * @group tour
 */
class LanguageTourTest extends TourTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'block',
    'language',
    'content_translation',
    'tour',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser([
      'administer content translation',
      'administer languages',
      'access tour',
    ]);
    $this->drupalLogin($this->adminUser);
    $this->drupalPlaceBlock('local_actions_block');
  }

  /**
   * Tests various language URLs for tours.
   */
  public function testVariousLanguageTours(): void {
    $this->testLanguageTour();
    $this->testLanguageAddTour();
    $this->testLanguageEditTour();
  }

  /**
   * Tests language tour tip availability.
   */
  protected function testLanguageTour(): void {
    $this->drupalGet('admin/config/regional/language');
    $this->assertTourTips();
  }

  /**
   * Go to add language page and check the tour tooltips.
   */
  protected function testLanguageAddTour(): void {
    $this->drupalGet('admin/config/regional/language/add');
    $this->assertTourTips();
  }

  /**
   * Go to edit language page and check the tour tooltips.
   */
  protected function testLanguageEditTour(): void {
    $this->drupalGet('admin/config/regional/language/edit/en');
    $this->assertTourTips();
  }

  /**
   * Go to edit language page and check the tour tooltips.
   */
  protected function testContentLanguageSettingsTour(): void {
    $this->drupalGet('admin/config/regional/content-language');
    $this->assertTourTips();
  }

}
