<?php

namespace Drupal\Tests\system\Functional;

use Drupal\Tests\dblog\Functional\FakeLogEntries;
use Drupal\Tests\tour\Functional\TourTestBase;

/**
 * Tests tour functionality.
 *
 * @group tour
 */
class SystemPageTourTests extends TourTestBase {

  use FakeLogEntries;

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['block', 'tour', 'system', 'dblog'];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser([
      'administer themes',
      'administer modules',
      'access site reports',
      'access tour',
    ]);
    $this->drupalLogin($this->adminUser);
    $this->drupalPlaceBlock('local_actions_block');
    $this->generateLogEntries(1);
  }

  /**
   * Test tips appear for various system pages.
   */
  public function testSystemRelatedPages(): void {
    $this->testAppearanceTour();
    $this->testExtendTour();
    $this->testDblogTour();
  }

  /**
   * Tests appearance tour tip availability.
   */
  protected function testAppearanceTour(): void {
    $this->drupalGet('admin/appearance');
    $this->assertTourTips();
  }

  /**
   * Tests modules extend tour tip availability.
   */
  protected function testExtendTour(): void {
    $this->drupalGet('admin/modules');
    $this->assertTourTips();
  }

  /**
   * Tests modules extend tour tip availability.
   */
  protected function testDblogTour(): void {
    $this->drupalGet('admin/reports/dblog');
    $this->assertTourTips();
  }

}
