<?php

namespace Drupal\Tests\user\Functional;

use Drupal\Tests\tour\Functional\TourTestBase;

/**
 * Tests tour functionality for user pages.
 *
 * @group tour
 */
class UserAdminTourTest extends TourTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['block', 'tour', 'user'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser([
      'administer users',
      'access tour',
    ]);
    $this->drupalLogin($this->adminUser);
    $this->drupalPlaceBlock('local_actions_block');
  }

  /**
   * Test tips appear for various user pages.
   */
  public function testUserRelatedPages(): void {
    $this->testAdminPeopleTour();
    $this->testUserCreateTourTips();
    $this->testUserEditTourTips();
  }

  /**
   * Tests user tour tip availability.
   */
  protected function testAdminPeopleTour(): void {
    $this->drupalGet('admin/people');
    $this->assertTourTips();
  }

  /**
   * Tests User Create tour tip availability.
   */
  protected function testUserCreateTourTips(): void {
    $this->drupalGet('admin/people/create');
    $this->assertTourTips();
  }

  /**
   * Tests User Edit tour tip availability.
   */
  protected function testUserEditTourTips(): void {
    $uid = $this->adminUser->id();
    $this->drupalGet('user/' . $uid . '/edit');
    $this->assertTourTips();
  }

}
